@@ -125,16 +125,18 @@ class Addon:
             where_install = join(addons_path, self.token)
             is_enabled = self.is_enable(environment)
             is_saned = self.is_saned(environment)
+            is_exists = os.path.exists(where_install)
             is_link = os.path.islink(where_install)
 
             if is_link:
-                if ((os.path.exists(where_install) and force) or \
-                   (is_enabled and force) or \
-                   (not is_saned)):
+                if ((is_exists and force) or \
+                    (is_enabled and force) or \
+                    (not is_saned)):
                     os.remove(where_install)
                 elif is_enabled and not force:
                     return False
 
+            if not os.path.exists(where_install):
                 os.symlink(self.path, where_install)
 
             return True
